In Vivo High Resolution Atlas of the Subcortical Human Brain


Notes
-----
The purpose of this project is to develop a crowd-sourced In Vivo High Resolution Atlas of the Subcortical Human Brain. 
We invite contributions to this project, both to increase the precision of anatomical labels, and to increase the number of labeled subcortical nuclei.

This resource can be used as a reference atlas for researchers and students alike.

Content
-------
    :'maps': Nifti images with the (probabilistic) region definitions
    :'labels': text file containing the file names

References
----------
For more information about this dataset:
https://osf.io/r2hvk/

Licence: UCC-By Attribution 4.0 International
